## Minimum hardware requirements for OAI CN5G and OAI gNB
    1. Operating System: Ubuntu 20.04.5 LTS
    3. CPU: 8 cores x86_64 @ 3.5 GHz
    2. RAM: 32 GB

## Minimum hardware requirements for OAI UE
    1. CPU: 4 cores x86_64
    2. RAM: 8 GB
    
## 5G Core Installation
### The following steps can be executed by the file oai_5g_core_install.sh
    1. First step is to download docker, docker-compose, git and network tools. 
    2. Following you need to download wireshark
        A. sudo add-apt-repository ppa:wireshark-dev/stable
        B. sudo apt update
        C. sudo apt install wireshark
    3. Git clone the 5GC
        A. git clone --branch v1.4.0 https://gitlab.eurecom.fr/oai/cn5g/oai-cn5g-fed.git
        B. Configuration of the packet forwarding
            - sudo sysctl net.ipv4.conf.all.forwarding=1
            - sudo iptables -P FORWARD ACCEPT
    4. Pulling the images from Docker Hub
        A. docker pull oaisoftwarealliance/oai-amf:v1.4.0
        B. docker pull oaisoftwarealliance/oai-nrf:v1.4.0
        C. docker pull oaisoftwarealliance/oai-smf:v1.4.0 
        D. docker pull oaisoftwarealliance/oai-spgwu-tiny:v1.4.0
        E. docker pull oaisoftwarealliance/oai-udr:v1.4.0
        F. docker pull oaisoftwarealliance/oai-udm:v1.4.0
        G. docker pull oaisoftwarealliance/oai-ausf:v1.4.0
        H. docker pull oaisoftwarealliance/oai-upf-vpp:v1.4.0
        I. docker pull oaisoftwarealliance/oai-nssf:v1.4.0
        J. docker pull oaisoftwarealliance/trf-gen-cn5g:latest
    5. Tag docker images
        A. docker image tag oaisoftwarealliance/oai-amf:v1.4.0 oai-amf:v1.4.0
        B. docker image tag oaisoftwarealliance/oai-nrf:v1.4.0 oai-nrf:v1.4.0
        C. docker image tag oaisoftwarealliance/oai-smf:v1.4.0 oai-smf:v1.4.0
        D. docker image tag oaisoftwarealliance/oai-spgwu-tiny:v1.4.0 oai-spgwu-tiny:v1.4.0
        E. docker image tag oaisoftwarealliance/oai-udr:v1.4.0 oai-udr:v1.4.0
        F. docker image tag oaisoftwarealliance/oai-udm:v1.4.0 oai-udm:v1.4.0
        G. docker image tag oaisoftwarealliance/oai-ausf:v1.4.0 oai-ausf:v1.4.0
        H. docker image tag oaisoftwarealliance/oai-upf-vpp:v1.4.0 oai-upf-vpp:v1.4.0
        I. docker image tag oaisoftwarealliance/oai-nssf:v1.4.0 oai-nssf:v1.4.0
        J. docker image tag oaisoftwarealliance/trf-gen-cn5g:latest trf-gen-cn5g:latest
    6. Synchronizing the tutorials
        A. Change the directory for ~/oai-cn5g-fed/
        B. ./scripts/syncComponents.sh
        C. git submodule deinit --all --force
        D. git submodule init
        F. git submodule update        
    7. Configure the bridge before deploying 5GC.
        A. docker network create \ --driver=bridge \ --subnet=192.168.70.128/26 \ -o "com.docker.network.bridge.name"="demo-oai" \ demo-oai-public-net
    8. Deploy the 5GC
        A. Change the directory for ~/oai-cn5g-fed/docker-compose
        B. python3 core-network.py --type start-basic --scenario 1

## FlexRIC, gNB and UE Installation
### The following steps can be executed by the file flexRIC_oai_gNB_install.sh
    1. Install the following dependencies
        A. sudo apt-get install autotools-dev
        B. sudo apt-get install automake
        C. sudo apt-get install libpcre2-dev
        D. sudo apt-get install pcre2-utils
        E. sudo apt-get install bison
        F. sudo apt-get install byacc
        G. sudo apt install g++
        H. sudo apt install libsctp-dev python3.8 cmake-curses-gui libpcre2-dev python3-dev    
    2. Configure swig
        A. git clone https://github.com/swig/swig.git 
        B. cd path_to_swig
        C. ./autogen.sh
        D. ./configure --prefix=/usr/
        E. sudo make
        F. sudo make install
    3. Install FlexRIC
        A. git clone https://gitlab.eurecom.fr/mosaic5g/flexric.git ~/flexric
        B. cd path_to_flexric
        C. git checkout v1.0.0
        D. mkdir build
        E. cd build
        F. sudo cmake ..
        G. sudo make
        H. sudo make install
    4. Install dependencies for OpenAirInterface 5G
        A. sudo add-apt-repository ppa:ettusresearch/uhd -y
        B. sudo apt-get update -y
        C. sudo apt-get install libuhd-dev uhd-host -y
        D. sudo apt-get install libuhd4.2.0 -y
        E. sudo dpkg -i --force-overwrite /var/cache/apt/archives/libuhd4.2.0_4.2.0.1-0ubuntu1~focal1_amd64.deb
    5. Download the OpenAirInterface 5G repository 
        A. git clone https://gitlab.eurecom.fr/oai/openairinterface5g.git oai
    6. Change the openairinterface 5G branch for 2022.41
        A. cd oai/
        B. git checkout 2022.41
    7. Apply FlexRIC patch
        A. git am <pathtoflexricsrc>/flexric/multiRAT/oai/oai.patch --whitespace=nowarn
    8. Download the OAI configuration files (CU/DU, OAI UE, and gNB configuration)
        A. sudo wget -O ~/oai/executables/nr-softmodem.c https://projetos.imd.ufrn.br/reginalab/sdran-openairinterface/-/raw/main/OpenAirInterface/OpenAirInterface-Conf/nr-softmodem.c?inline=false
        B. sudo wget -O ~/oai/ci-scripts/conf_files/gNB_SA_CU.conf https://projetos.imd.ufrn.br/reginalab/sdran-openairinterface/-/raw/main/OpenAirInterface/OpenAirInterface-Conf/gNB_SA_CU.conf?inline=false
        C. sudo wget -O ~/oai/ci-scripts/conf_files/gNB_SA_DU.conf https://projetos.imd.ufrn.br/reginalab/sdran-openairinterface/-/raw/main/OpenAirInterface/OpenAirInterface-Conf/gNB_SA_DU.conf?inline=false
        D. sudo wget -O ~/oai/targets/PROJECTS/GENERIC-NR-5GC/CONF/ue.conf https://projetos.imd.ufrn.br/reginalab/sdran-openairinterface/-/raw/main/OpenAirInterface/OpenAirInterface-Conf/ue.conf?inline=false

    9. Install the gNB and UE
        A. source oaienv
        B. cd cmake_targets
        C. ./build_oai -I -w USRP -i  #For OAI first time installation. it will install some dependencies
        D. ./build_oai --gNB --nrUE -c -C -w USRP --ninja --build-lib all

